sumo
====

About
-----

sumo, the SUpport MOdule manager, is a set of tools to support software
development for the `EPICS <https://epics.anl.gov>`_ framework. It manages
build dependencies and consistent builds of the 
`EPICS <https://epics.anl.gov>`_ base and `EPICS <https://epics.anl.gov>`_
support modules.

Author
------

Goetz Pfeiffer <Goetz.Pfeiffer@helmholtz-berlin.de>

Documentation
-------------

Documentation is available online here:

`sumo documentation <https://epics-sumo.sourceforge.io>`_.

Documentation is also included in the software distribution in HTML format.

Installation
------------

You can install sumo with `pip <https://pip.pypa.io/en/stable>`_
(python package manager), as 
`debian <https://www.debian.org/distrib/packages>`_  or 
`rpm <http://rpm.org>`_  package or from 
`source <https://docs.python.org/3/install>`_.

All is described here:

`sumo install <https://epics-sumo.sourceforge.io/sumo-install.html>`_.

License
-------

Sumo is licensed under GNU GPL v.3. Here is the license text:

`sumo license <https://epics-sumo.sourceforge.io/license.html>`_.

